@@ -1,7 +1,7 @@
 package Log::ger;
 
-our $DATE = '2017-08-03'; # DATE
-our $VERSION = '0.023'; # VERSION
+our $DATE = '2018-12-20'; # DATE
+our $VERSION = '0.024'; # VERSION
 
 #IFUNBUILT
 # use strict;
@@ -166,7 +166,7 @@ Log::ger - A lightweight, flexible logging framework
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 SYNOPSIS
 
@@ -219,7 +219,8 @@ try yourself e.g. with L<bencher-code>:
  % bencher-code 'use Log::ger' 'use Log::Any' --startup
 
 B<Fast>. Low null-/stealth-logging overhead, about 1.5x faster than Log::Any, 3x
-faster than Log4perl, and 5x faster than L<Log::Fast>.
+faster than Log4perl, 5x faster than L<Log::Fast>, and ~100x faster than
+L<Log::Dispatch>.
 
 B<Conditional compilation.> There is a plugin to optimize away unneeded logging
 statements, like assertion/conditional compilation, so they have zero runtime
@@ -272,7 +273,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
